@@ -8,6 +8,8 @@ from cart.cart import (
     unpack_file,
     get_metadata_only,
     is_cart,
+    async_unpack_iterable,
+    async_pack_iterable,
     MANDATORY_HEADER_FMT,
     MANDATORY_FOOTER_FMT,
     DEFAULT_ARC4_KEY,
